==> libgal-0.2.0.tar.gz: libgal-0.2.0/vec_mat/gal_pas.c <==
/*  
 *  - - - - - - - -  
 *   g a l _ p a s  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Position-angle from spherical coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     al                  d        longitude of point A (e.g. RA) in radians  
 *     ap                  d        latitude of point A (e.g. Dec) in radians  
 *     bl                  d        longitude of point B  
 *     bp                  d        latitude of point B  
 *  
 *  Returned:
 *  
 *     *theta              d        position angle of B with respect to A  
 *  
 *  Notes:  
 *  
 *  1) The result is the bearing (position angle), in radians, of point  
 *     B with respect to point A.  It is in the range -pi to +pi.  The  
 *     sense is such that if B is a small distance "east" of point A,  
 *     the bearing is approximately +pi/2.  
 *  
 *  2) Zero is returned if the two points are coincident.  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_pas.h"  
  
void  
gal_pas  
 (  
    double al,  
    double ap,  
    double bl,  
    double bp,  
    double *theta  
 )  
{  
  
    double dl, x, y ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    dl = bl - al ;  
    y = sin ( dl ) * cos ( bp ) ;  
    x = sin ( bp ) * cos ( ap ) - cos ( bp) * sin ( ap ) * cos ( dl ) ;  
    if ( x != 0.0 || y != 0.0 ) {  
        *theta = atan2 ( y, x ) ;  
    }  
    else {  
        *theta = 0.0 ;  
    }  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.5.0.tar.gz: libgal-0.5.0/vec_mat/gal_pas.c <==
/*  
 *  - - - - - - - -  
 *   g a l _ p a s  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Position-angle from spherical coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     al                  d        longitude of point A (e.g. RA) in radians  
 *     ap                  d        latitude of point A (e.g. Dec) in radians  
 *     bl                  d        longitude of point B  
 *     bp                  d        latitude of point B  
 *  
 *  Returned:
 *  
 *     gal_pas             d        position angle of B with respect to A  
 *  
 *  Notes:  
 *  
 *  1) The result is the bearing (position angle), in radians, of point  
 *     B with respect to point A.  It is in the range -pi to +pi.  The  
 *     sense is such that if B is a small distance "east" of point A,  
 *     the bearing is approximately +pi/2.  
 *  
 *  2) Zero is returned if the two points are coincident.  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_pas.h"  
  
double  
gal_pas  
 (  
    double al,  
    double ap,  
    double bl,  
    double bp  
 )  
{  
  
    double dl, x, y, theta ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    dl = bl - al ;  
    y = sin ( dl ) * cos ( bp ) ;  
    x = sin ( bp ) * cos ( ap ) - cos ( bp) * sin ( ap ) * cos ( dl ) ;  
    if ( x != 0.0 || y != 0.0 ) {  
        theta = atan2 ( y, x ) ;  
    }  
    else {  
        theta = 0.0 ;  
    }
    
    return theta ;
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
